#coding=utf-8
from distutils.core import setup

setup(
    name='N0ShellAPI',
    version='0.0.1',
    license='Free',
    author='N0P3',
    author_email='n0p3@qq.com',
    url='https://blog.n0p3.cn/2021/01/14/N0Shell/',
    description='提供在N0Shell中开发程序的API。',
    long_description='当前是早期测试版本，部分API未来可能会发生变化或取消。',
    py_modules=['N0ShellAPI.graphic'],
    )